/*
This is a module for Litestep which let you define hotspots for
executing bang commands or launching programs

Copyright (C) 2003 Eric Moore
Copyright (C) 2000 Chao-Kuo Lin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#pragma comment( lib, "lsapi.lib" )

#define STRICT
#define WIN32_LEAN_AND_MEAN
#include <windows.h>

#include <stdlib.h>
#include "../ls-old/lsapi/lsapi.h"
#include "../ls-old/lsapi/macros.h"
#include "ckHotspots.h"

HWND g_HotspotHWND = NULL;


////////////////////////////////
//helper functions
//change so that coord will not be < 0
//void AdjustCoordinate(int *coord, int inc);

// turn on and off the hotspot system, when on, the system
// will check for mouse movement and stuff
void SystemOn(void);
void SystemOff(void);

// this function will adjust to turn system on or off
// depend on whether all hotspots or activated or deactivated
void SystemAdjust(void);


void SetMouseHook(void);
void RemoveMouseHook(void);
BOOL LoadHookSettings();
void UnloadHookSettings();


///////////////////////////////////
//hook functions
//our mouse call back function
//LRESULT CALLBACK MouseProc(int nCode, WPARAM wParam, LPARAM lParam);
//setup the mouse hook	
//void SetMouseHook(void);
//void RemoveMouseHook(void);
HINSTANCE g_HookInstance = NULL;
SETMOUSEHOOK SetMouseHookFunc = NULL;


//////////////////////////////////
//bang functions
//usual toggle functions
void BangOn(HWND caller, LPCSTR args);
void BangOff(HWND caller, LPCSTR args);
void BangToggle(HWND caller, LPCSTR args);

//dynamic add 
void BangAdd(HWND caller, LPCSTR args);
void BangRemove(HWND caller, LPCSTR args);

//Added by Eric Moore 2003-04-27
void BangAdjust(HWND caller, LPCSTR args);


// global variables
HINSTANCE g_hInstance = NULL;
UINT g_Timer = 0;
HotspotT g_Hotspots[MAX_HOTSPOTS];
int g_Count = 0;
int g_LastSpot = -1;
//HWND g_HotspotHWND = NULL;
POINT g_LastPt= {0, 0};
UINT Msgs[] = { LM_GETREVID, 0};
//true means all spots checking on,  false means all spot checking off
//-1 means that some are on some are off
BOOL g_Status = -1; 
BOOL g_Version1Style = FALSE;
BOOL g_MouseHookStyle = FALSE;

//get screen dimention
int ScreenWidth, ScreenHeight;

static const char rcsRevision[] = "$Revision: 2.3 (Chaku, Hollow)$";
static const char rcsId[] = "$Id: ckHotspots v2.3 2003-04-27 Chao-Kuo Lin, Hollow $";

/////////////////////////////
// windows callback function
LRESULT CALLBACK WindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
{
switch (uMsg) 
{
	
	// user defined window message which is sent from our mouse hook
	// wParam contains the y coordinate while lParam contains the x coordinate
	case WM_CKMOUSEHOOKMSG:
		{
            POINT pt;
			int i;

            if(g_Status)
            {
			    pt.x = lParam;
			    pt.y = wParam;
		    
			    //if anything changed
			    if(g_LastPt.x != pt.x || g_LastPt.y != pt.y)
			    {
				    //we entered already, if mouse out, then we call the out action
				    if(g_LastSpot >= 0 && !PtInRect(&(g_Hotspots[g_LastSpot].spot), pt) )
				    {
					    if(g_Hotspots[g_LastSpot].stat == TRUE)
						    LSExecute(hwnd, g_Hotspots[g_LastSpot].out_action, SW_SHOWDEFAULT);
					    
					    //if the spot was disabled or removed we reset the last spot
					    g_LastSpot = -1;
				    }

				    if(g_LastSpot < 0)
				    {
					    for(i=0; i<g_Count; ++i)
					    {
						    if((g_Hotspots[i].stat == TRUE) && PtInRect(&(g_Hotspots[i].spot), pt))
						    {
							    LSExecute(hwnd, g_Hotspots[i].in_action, SW_SHOWDEFAULT);
							    g_LastSpot = i;
							    break; // we don't do overlap ones
						    }
					    }
				    }

				    g_LastPt = pt;
			    }
            }
		}
		break;

	case WM_TIMER:
		{
			POINT pt;
			int i;
            
            if(g_Status)
            {
			    if(GetCursorPos(&pt))
			    {
				    //if anything changed
				    if(g_LastPt.x != pt.x || g_LastPt.y != pt.y)
				    {
					    //we entered already, if mouse out, then we call the out action
					    if(g_LastSpot >= 0 && !PtInRect(&(g_Hotspots[g_LastSpot].spot), pt) )
					    {
						    if(g_Hotspots[g_LastSpot].stat == TRUE)
							    LSExecute(hwnd, g_Hotspots[g_LastSpot].out_action, SW_SHOWDEFAULT);
						    
						    //if the spot was disabled or removed we reset the last spot
						    g_LastSpot = -1;
					    }

					    if(g_LastSpot < 0)
					    {
						    for(i=0; i<g_Count; ++i)
						    {
							    if((g_Hotspots[i].stat == TRUE) && PtInRect(&(g_Hotspots[i].spot), pt))
							    {
								    LSExecute(hwnd, g_Hotspots[i].in_action, SW_SHOWDEFAULT);
								    g_LastSpot = i;
								    break; // we don't do overlap ones
							    }
						    }
					    }

					    g_LastPt = pt;
				    }
			    }
            }
		}
		break;

	case LM_GETREVID: 
		{
			PTSTR buffer = (PTSTR)lParam;
			
			if (wParam == 0)
			{
				strcpy(buffer, "ckHotpots: ");
				strcat(buffer, &rcsRevision[11]);
				buffer[strlen(buffer)-1] = 0;
			}
			else if (wParam == 1)
			{
				strcpy(buffer, &rcsId[5]);
				buffer[strlen(buffer)-1] = 0;
			} else
			{
				strcpy(buffer, "");
			}
			return strlen(buffer);
		}
		break;
  

	default:
		return DefWindowProc (hwnd, uMsg, wParam, lParam);
	}

	return 0;
}


////////////////////////////////
// Bang callback functions


//BangOn
//	args will be the name of the spot to turn on,
//	if no args or arges len == 0, then it's all the area we are toggling
void BangOn(HWND caller, LPCSTR args)
{	
	int i;
	if(!args || strlen(args) == 0)
	{//turn all on
		for(i=0; i<g_Count; ++i)
		{
			if(g_Hotspots[i].stat == -1) continue;
			
			g_Hotspots[i].stat = TRUE;				
		}
		SystemOn();
	}
	else	
	{
		for(i=0; i<g_Count; ++i)
		{
			if(g_Hotspots[i].stat == -1) continue;
			
			if(stricmp(g_Hotspots[i].name, args) == 0)
			{
				g_Hotspots[i].stat = TRUE;				
				break;
			}
		}

		SystemAdjust();
	}
}

void BangOff(HWND caller, LPCSTR args)
{
	int i;
	if(!args || strlen(args) == 0)
	{//turn all off
		for(i=0; i<g_Count; ++i)
		{
			if(g_Hotspots[i].stat == -1) continue;
			g_Hotspots[i].stat = FALSE;				
		}

		SystemOff();
	}
	else	
	{
		for(i=0; i<g_Count; ++i)
		{
			if(g_Hotspots[i].stat == -1) continue;
			
			if(stricmp(g_Hotspots[i].name, args) == 0)
			{
				g_Hotspots[i].stat = FALSE;				
				break;
			}
		}

		SystemAdjust();
	}
}

void BangToggle(HWND caller, LPCSTR args)
{
	int i;
	if(!args || strlen(args) == 0)
	{//flip all!
		for(i=0; i<g_Count; ++i)
		{
			if(g_Hotspots[i].stat == -1) continue;
			g_Hotspots[i].stat = !g_Hotspots[i].stat;				
		}
	}
	else	
	{
		for(i=0; i<g_Count; ++i)
		{
			if(g_Hotspots[i].stat == -1) continue;
			
			if(stricmp(g_Hotspots[i].name, args) == 0)
			{
				g_Hotspots[i].stat = !g_Hotspots[i].stat;				
				break;
			}
		}
	}

	SystemAdjust();
}

void BangAdd(HWND caller, LPCSTR args)
{
	int i;
	
	for(i=0; i<g_Count; ++i)
	{
		if(g_Hotspots[i].stat == -1) break;
	}

	if(i >= MAX_HOTSPOTS) 
	//change to a warning box
		MessageBox(NULL, "Cannot add anymore spots!", "ckHotspots", MB_OK);
	else
	{
		int count = 0;
		char *lpszBuffers[10];
		char token1[MAX_LINE_LENGTH], token2[MAX_LINE_LENGTH], token3[MAX_LINE_LENGTH], token4[MAX_LINE_LENGTH], 
			token5[MAX_LINE_LENGTH], token6[MAX_LINE_LENGTH], token7[MAX_LINE_LENGTH], token8[MAX_LINE_LENGTH];
		token1[0] = token2[0] = token3[0] = token4[0] = 
		token5[0] = token6[0] = token7[0] = token8[0] = '\0';
		
		lpszBuffers[0] = token1;	// x1
		lpszBuffers[1] = token2;	// y1
		lpszBuffers[2] = token3;	// width
		lpszBuffers[3] = token4;	// height
		lpszBuffers[4] = token5;	// mouse in action
		lpszBuffers[5] = token6;	// mouse out action
		lpszBuffers[6] = token7;	// hotspot name
		lpszBuffers[7] = token8;	// hotspot status

		count = LCTokenize(args, lpszBuffers, 8, NULL);
		if(count >= 6)
		{
			g_Hotspots[i].stat = TRUE; // defaul to hotspot "on"
			g_Hotspots[i].name[0] = '\0'; 
			
			g_Hotspots[i].spot.left = atoi(token1);
			g_Hotspots[i].spot.top = atoi(token2);
			g_Hotspots[i].spot.right = atoi(token3);
			g_Hotspots[i].spot.bottom = atoi(token4);
			g_Hotspots[i].spot.left = CONVERT_COORDINATE_X(g_Hotspots[i].spot.left);
			g_Hotspots[i].spot.right = CONVERT_COORDINATE_X(g_Hotspots[i].spot.right);
			g_Hotspots[i].spot.top = CONVERT_COORDINATE_Y(g_Hotspots[i].spot.top);
			g_Hotspots[i].spot.bottom = CONVERT_COORDINATE_Y(g_Hotspots[i].spot.bottom);
			//AdjustCoordinate(&(g_Hotspots[i].spot.left), ScreenWidth);
			//AdjustCoordinate(&(g_Hotspots[i].spot.right), ScreenWidth);
			//AdjustCoordinate(&(g_Hotspots[i].spot.top), ScreenHeight);
			//AdjustCoordinate(&(g_Hotspots[i].spot.bottom), ScreenHeight);

			if(g_Hotspots[i].spot.right == 0)
				g_Hotspots[i].spot.right = ScreenWidth;
			else 
				g_Hotspots[i].spot.right += g_Hotspots[i].spot.left;

			if(g_Hotspots[i].spot.bottom == 0)
				g_Hotspots[i].spot.bottom = ScreenHeight;
			else
				g_Hotspots[i].spot.bottom += g_Hotspots[i].spot.top;

			strcpy(g_Hotspots[i].in_action, token5);
			strcpy(g_Hotspots[i].out_action, token6);
			
			if(count >= 7) // copy the name
				strcpy(g_Hotspots[i].name, token7);
			
			if(count == 8)
			{
				if(stricmp(token8, "on") == 0 || stricmp(token8, "true") == 0 || stricmp(token8, "yes") == 0)
				{
					g_Hotspots[i].stat = TRUE;
				}
				else if(stricmp(token8, "off") == 0 || stricmp(token8, "false") == 0 || stricmp(token8, "no") == 0)
				{
					g_Hotspots[i].stat = FALSE;
				}
			}
			
			if(i == g_Count)
				++g_Count;

			/*
			wsprintf(token1, "Spot # %d : (%d, %d), (%d, %d)\nIn action:%s\nOut action:%s",
							i, g_Hotspots[i].spot.left, g_Hotspots[i].spot.top,
							g_Hotspots[i].spot.right, g_Hotspots[i].spot.bottom,
							g_Hotspots[i].in_action, g_Hotspots[i].out_action);
			MessageBox(NULL, token1, "ckHotspots", MB_OK);
			*/

			SystemAdjust();
		}
		else
		{
			//change it to a warning box
			MessageBox(NULL, "Invalid ckHotspots config found!", "ckHotspots", MB_OK);
		}
		
	}	


}

void BangRemove(HWND caller, LPCSTR args)
{
	int i;

	if(args && strlen(args))
	{
		for(i=0; i<g_Count; ++i)
		{
			if(g_Hotspots[i].stat == -1) continue;
			if(stricmp(g_Hotspots[i].name, args) == 0)
				g_Hotspots[i].stat = -1;
		}
	}	
}

// added by Eric Moore 2003-04-27 
void BangAdjust(HWND caller, LPCSTR args)
{
	// !HotspotAdjust name dx dy dw dh 
	int i;
	char *buffers[5];
	char name[MAX_LINE_LENGTH], dx[MAX_LINE_LENGTH], dy[MAX_LINE_LENGTH],
		dw[MAX_LINE_LENGTH], dh[MAX_LINE_LENGTH], extra[MAX_LINE_LENGTH];
	name[0] = dx[0] = dy[0] = dw[0] = dh[0] = extra[0] = '\0';
	buffers[0] = name;
	buffers[1] = dx;
	buffers[2] = dy;
	buffers[3] = dw;
	buffers[4] = dh;
	
	if(LCTokenize(args, buffers, 5, extra) == 5)
	{
		for(i=0; i<g_Count; ++i)
		{
			if(stricmp(g_Hotspots[i].name, name) == 0)
			{
				int NewX, NewY, NewW, NewH;
				NewX = g_Hotspots[i].spot.left + atoi(dx);
				NewY = g_Hotspots[i].spot.top + atoi(dy);
				NewW = g_Hotspots[i].spot.right - g_Hotspots[i].spot.left + atoi(dw);
				NewH = g_Hotspots[i].spot.bottom - g_Hotspots[i].spot.top + atoi(dh);

				// is this new area on the screen? a little sanity checking.
				if(NewX < 0)
					NewX = 0;
				if(NewX > ScreenWidth)
					NewX = ScreenWidth;

				if(NewY < 0)
					NewY = 0;
				if(NewY > ScreenHeight)
					NewY = ScreenHeight;

				if(NewW < 0)
					NewW = 0;
				if(NewX + NewW > ScreenWidth)
					NewW = ScreenWidth - NewX;

				if(NewH < 0)
					NewH = 0;
				if(NewY + NewH > ScreenHeight)
					NewH = ScreenHeight - NewY;

				g_Hotspots[i].spot.left = NewX;
				g_Hotspots[i].spot.top = NewY;
				g_Hotspots[i].spot.right = NewX + NewW;
				g_Hotspots[i].spot.bottom = NewY + NewH;
				break;
			}
		}
	}
	else
	{
		MessageBox(NULL,"Incorrect number of arguments in !HotspotAdjust\nUsage:\n\t!HotspotAdjust name dx dy dw dh", "ckHotspots", MB_OK);
	}
}


void BangDebug(HWND caller, LPCSTR args)
{
	int i;
	char buffer[4096];
	for(i=0; i<g_Count; ++i)
	{
		wsprintf(buffer, "Spot # %d : (%d, %d), (%d, %d)\nIn action:%s\nOut action:%s\nName:%s",
					i, g_Hotspots[i].spot.left, g_Hotspots[i].spot.top,
					g_Hotspots[i].spot.right, g_Hotspots[i].spot.bottom,
					g_Hotspots[i].in_action, g_Hotspots[i].out_action,
					g_Hotspots[i].name);
		MessageBox(NULL, buffer, "ckHotspots", MB_OK);
	}
	

}

///////////////////////////////
// Litestep module specific functions
int initModule(HWND parent, HINSTANCE dll, wharfDataType* wd)
{
	return initModuleEx(parent, dll, (wd)? wd->lsPath : NULL);	
}

int initModuleEx(HWND parent, HINSTANCE dll, LPCSTR szPath)
{
	//const char lpszClassName[] = "ckHotspots";
	
	FILE *f;
	
	char buffer[MAX_LINE_LENGTH];
	int Timerout = 100;
	WNDCLASS wc;

	//save screen dimension
	ScreenWidth = SCREEN_WIDTH;
	ScreenHeight = SCREEN_HEIGHT;
	

	memset(&wc, 0, sizeof (wc));
	
	wc.lpfnWndProc = WindowProc;
	wc.hInstance = g_hInstance;
	wc.lpszClassName = CKHOTSPOTSCLASSNAME;
	
	//register window
	if(!RegisterClass(&wc))
	{
		MessageBox(NULL, "ckHotspots failed to register class", "Error", MB_OK);
		return -1; //failed	
	}

	//create window
	g_HotspotHWND = 
		CreateWindowEx(WS_EX_TOOLWINDOW, wc.lpszClassName, wc.lpszClassName, 
		0, 0, 0, 0, 0, NULL, NULL, dll, NULL);
	

	if(!g_HotspotHWND)
	{
		MessageBox(NULL, "ckHotspots failed to create window", "Error", MB_OK);
		return -1; //failed
	}

	//exclude ourselves from vwm
	SetWindowLong(g_HotspotHWND, GWL_USERDATA, magicDWord);
	
	//Which engine to employ
	g_Version1Style = GetRCBool("ckHotspotsVersion1Style", TRUE);
    g_MouseHookStyle = GetRCBool("ckHotspotsMouseHookStyle", TRUE);
    if(GetRCBool("IHaveAlotOfResourcesAndIReallyWantSomeVeryQuickStyle", TRUE))
    {
        g_Version1Style = g_MouseHookStyle = TRUE;
    }

	//read in all the configs
	f = LCOpen(NULL);
	if (f) 
	{	
		char *ConfigToken;
		
		while (LCReadNextConfig (f, "*ckHotspot", buffer, sizeof (buffer)))
		{
			//GetToken(buffer, NULL, &ConfigToken, FALSE);
			//the following will the the same thing as above function
			ConfigToken = buffer;
			while(!isspace(*ConfigToken++));
			
			while(isspace(*ConfigToken))
				++ConfigToken;

			BangAdd(g_HotspotHWND, ConfigToken);
		}
		LCClose(f);

		/*
		wsprintf(buffer, "Total %d spots", g_Count);
		MessageBox(NULL, buffer, "ckHotspots", MB_OK);
		*/
	}	

	//register message
	SendMessage(GetLitestepWnd(), LM_REGISTERMESSAGE, (WPARAM)g_HotspotHWND, (LPARAM)Msgs);

	//set up bangs
	AddBangCommand("!HotspotON", BangOn);
	AddBangCommand("!HotspotOFF", BangOff);
	AddBangCommand("!HotspotToggle", BangToggle);
	AddBangCommand("!HotspotAdd", BangAdd);
	AddBangCommand("!HotspotRemove", BangRemove);
	//Added by Eric Moore 2003-04-27
	AddBangCommand("!HotspotAdjust", BangAdjust);

	AddBangCommand("!HotspotDebug", BangDebug);

    // if user didn't specify anything, the default is using version1 style!
    if(!g_Version1Style && !g_MouseHookStyle)
    {
        g_Version1Style = TRUE;
    }

    if(g_MouseHookStyle)
	{
		//load library then initialize
		INITHOOK initHook = NULL;
		if(LoadHookSettings())
        {
		    initHook = (INITHOOK) GetProcAddress(g_HookInstance, "InitializeHook");
		    initHook(g_HotspotHWND, WM_CKMOUSEHOOKMSG);
        }
        else
        {
            g_MouseHookStyle = FALSE;
            MessageBox(NULL, "Deafult style will be used", "ckHotspots", MB_OK);
            g_Version1Style = TRUE;
        }
	}

    if(g_Version1Style)
	{//Set our timer
		Timerout = GetRCInt("ckHotspotsTimeOut", Timerout);
		g_Timer	= SetTimer(g_HotspotHWND, 1, Timerout, NULL);
		if(g_Timer == 0)
		{
			MessageBox(NULL, "ckHotspots failed to set timer", "Error", MB_OK);
            g_Version1Style = FALSE;
		}
	}

    if(!g_Version1Style && !g_MouseHookStyle)
    {
        //both style failed
        SystemOff();
        return -1;
    }

	SystemAdjust();

	return 0; // success
}

int quitModule(HINSTANCE dll)
{
	if(g_Timer != 0)
		KillTimer(g_HotspotHWND , 1);
	
	SystemOff();
	
	//set up bangs
	RemoveBangCommand("!HotspotON");
	RemoveBangCommand("!HotspotOFF");
	RemoveBangCommand("!HotspotToggle");
	RemoveBangCommand("!HotspotAdd");
	RemoveBangCommand("!HotspotRemove");
	//Added By Eric Moore 2003-04-27
	RemoveBangCommand("!HotspotAdjust");

	RemoveBangCommand("!HotspotsDebug");

	SendMessage(GetLitestepWnd(), LM_UNREGISTERMESSAGE, (WPARAM)g_HotspotHWND, (LPARAM)Msgs);

	DestroyWindow(g_HotspotHWND);
	UnregisterClass(CKHOTSPOTSCLASSNAME, g_hInstance);

	//MessageBox(NULL, "returning from quit", "ckHotspots", MB_OK);

	if(g_MouseHookStyle)
	{
		int i;
		//let's loop a bit to make sure it's unloaded
		for(i=0; i<10 || g_HookInstance != NULL; ++i)
			UnloadHookSettings();
		//we got a problem
		if(g_HookInstance != NULL)
			return 1;
	}

	return 0;
}

///////////////////////////////////
// helper functions

// add inc to coord until coord > 0, and coord will be < than inc, otherwise coord = inc
/*
void AdjustCoordinate(int *coord, int inc)
{
	while(*coord < 0)
		*coord += inc;

	if(*coord > inc) *coord = inc;
}
*/
// turn on and off the hotspot system, when on, the system
// will check for mouse movement and stuff
void SystemOn(void)
{
	if(g_MouseHookStyle)
		SetMouseHook();
	g_Status = TRUE;
}

void SystemOff(void)
{
	g_Status = FALSE;
	if(g_MouseHookStyle)
		RemoveMouseHook();
}

// this function will adjust to turn system on or off
// depend on whether all hotspots or activated or deactivated
void SystemAdjust(void)
{
	int i;
	BOOL flag;
    
    if(g_Version1Style || g_MouseHookStyle)
    {
	    for(i=0; (i<g_Count) && (flag == -1); ++i)
	    {
		    flag = g_Hotspots[i].stat;
	    }

	    for(++i; i<g_Count; ++i)
	    {
		    if(g_Hotspots[i].stat != -1 && flag != g_Hotspots[i].stat) break;
	    }

	    //all same
	    if(i >= g_Count)
		    (flag) ? SystemOn() : SystemOff();
	    else //if something's on then we must have system on
		    SystemOn();
    }
}

/////////////////////////////
// Hook functions

//our mouse call back function
/*
LRESULT CALLBACK MouseProc(int nCode, WPARAM wParam, LPARAM lParam)
{
	MOUSEHOOKSTRUCT *ptr;
	//HWND ckHotspotsHWND;

	if(nCode < 0)
		return CallNextHookEx(g_Hook, nCode, wParam, lParam);
	
	//ckHotspotsHWND = FindWindow(CKHOTSPOTSCLASSNAME, NULL);
	if(g_HotspotHWND)
	{
		if(wParam == WM_MOUSEMOVE || wParam == WM_NCMOUSEMOVE)
		{
			ptr = (MOUSEHOOKSTRUCT *)lParam;
			PostMessage(g_HotspotHWND, WM_CKMOUSEHOOKMSG, ptr->pt.y, ptr->pt.x);
		}
	}

	return 0;
}
*/


//setup the mouse hook	
void SetMouseHook(void)
{
	if(SetMouseHookFunc != NULL)
		SetMouseHookFunc(TRUE);
}

void RemoveMouseHook(void)
{
	if(SetMouseHookFunc != NULL);
		SetMouseHookFunc(FALSE);
}

BOOL LoadHookSettings()
{
	if(g_HookInstance == NULL)
	{
		g_HookInstance = LoadLibrary("ckMouseHook.dll");
		if(g_HookInstance != NULL)
		{
			SetMouseHookFunc = (SETMOUSEHOOK) GetProcAddress(g_HookInstance, "SetMouseHook");
		}

		if(g_HookInstance == NULL || SetMouseHookFunc == NULL)
		{
			MessageBox(NULL, "ckMouseHook.dll failed to load, please make sure ckMouseHook.dll is in the same directory as litestep.exe and lsapi.dll", "ckHotspots", MB_OK);
		}
	}

    return (g_HookInstance != NULL && SetMouseHookFunc != NULL);
}

void UnloadHookSettings()
{
	if(g_HookInstance != NULL)
	{
		if(FreeLibrary(g_HookInstance))
		{
			SetMouseHookFunc = NULL;
			g_HookInstance = NULL;
		}

	}
}

////////////////////////////////////
// main entry function
//our DLL entry point
BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
{
	UNREFERENCED_PARAMETER(lpvReserved);
	if(fdwReason == DLL_PROCESS_ATTACH)
	{
		g_hInstance = hinstDLL;
		DisableThreadLibraryCalls(g_hInstance);
	}
	return TRUE;
}


